
# Chen, Pan, and Xu "Sources of Authoritarian Responsiveness: A Field Experiment in China"
# Replication File -- Table 3 Column (5)

rm(list=ls(all=TRUE))

#############################
# ratio of public response
#############################

# load data
library(foreign)
d <- read.dta("forum.dta")
names(d)

# split data into four groups
d0<-subset(d,treat==0)
d1<-subset(d,treat==1)
d2<-subset(d,treat==2)
d3<-subset(d,treat==3)
n0<-dim(d0)[1];n1<-dim(d1)[1];n2<-dim(d2)[1];n3<-dim(d3)[1]

# point estimate
ratio0<-sum(d0$response==1&d0$response_public)/sum(d0$response==1)
ratio1<-sum(d1$response==1&d1$response_public)/sum(d1$response==1)
ratio2<-sum(d2$response==1&d2$response_public)/sum(d2$response==1)
ratio3<-sum(d3$response==1&d3$response_public)/sum(d3$response==1)
c(ratio1-ratio0,ratio2-ratio0,ratio3-ratio0,ratio0)  

# bootstrap
nboots<-1000
results<-matrix(NA,4,nboots)

set.seed(123)
for (i in 1:nboots) {
  s0<-d0[sample(1:n0,n0,replace=TRUE),]
  s1<-d1[sample(1:n1,n1,replace=TRUE),]
  s2<-d2[sample(1:n2,n2,replace=TRUE),]
  s3<-d3[sample(1:n3,n3,replace=TRUE),]
  ratio0<-sum(s0$response==1&s0$response_public)/sum(s0$response==1)
  ratio1<-sum(s1$response==1&s1$response_public)/sum(s1$response==1)
  ratio2<-sum(s2$response==1&s2$response_public)/sum(s2$response==1)
  ratio3<-sum(s3$response==1&s3$response_public)/sum(s3$response==1)
  results[1,i]<-ratio1-ratio0
  results[2,i]<-ratio2-ratio0
  results[3,i]<-ratio3-ratio0
  results[4,i]<-ratio0  
}  

# standard errors
apply(results,1,sd)

# 95% confidence intervals
apply(results,1,quantile,c(0.025,0.975))


