# Chen, Pan, and Xu "Sources of Authoritarian Responsiveness: A Field Experiment in China"
# Replication File -- Figures 2, 3, 4, 5, 6, and 7

rm(list=ls(all=TRUE))
library(foreign)
library(plyr)
library(mlogit)


#######################
## Descriptive Stats 
#######################


des <-as.matrix(read.dta("fg_balance.dta"))
variables<-c("Attempted","Successful post","Existing posts","Recent posts","Immediately viewable",
             "Requiring real name","Requiring phone number","Requiring email address","Requiring address","Requiring ID number")
rownames(des) <- variables

# Figure 1. availability of county government web forums
par(mar=c(6, 4, 2, 1) + 0.1, xpd=TRUE)
plot(c(1:4,6:9),c(des[1,1:4],des[2,1:4]), pch=rep(c(18,15:17),2), ylim=c(0,1), xlim=c(0.5,9.5), ylab="Proportion of All Counties",xlab="",xaxt="n", cex.axis=1.5, cex.lab=1.5, cex = 1.5)
axis(1,c(1:4,6:9),labels= rep(c("C","T1","T2","T3"),2), cex.axis=1.5, mgp=c(3,1,0))
mtext("Government Websites\nwith Forums", 1,at=2.5,line=4,cex=1.5)
mtext("Successful Posts\nto Forums",1,at=7.5,line=4,cex=1.5)
segments(5,-0.04,5,1.04)
for(i in 1:4){
  segments(i,des[1,i+4],i,des[1,i+8])
  segments(i+5,des[2,i+4],i+5,des[2,i+8])
}


# Figure 2. openness of couty govenrment web forums
par(mar=c(6, 4, 2, 1) + 0.1, xpd=TRUE)
plot(c(1:4,6:9,11:14),c(des[3,1:4],des[4,1:4],des[5,1:4]), pch=rep(c(18,15:17),3), ylim=c(0,1), xlim=c(0.5,14.5), ylab="Proportion of Counties with Forums",xlab="",xaxt="n", cex.axis=1.5, cex.lab=1.5, cex = 1.3)
axis(1,c(1:4,6:9,11:14),labels= rep(c("C","T1","T2","T3"),3), cex.axis=1.5, mgp=c(3,1,0))
mtext("Contains Any\nPublic Replies", 1,at=2.5,line=4,cex=1.5)
mtext("Contains Recent\nPublic Replies",1,at=7.5,line=4,cex=1.5)
mtext("Submission\nInstantly Viewable",1,at=12.5,line=4,cex=1.5)
segments(5,-0.04,5,1.04)
segments(10,-0.04,10,1.04)
for(i in 1:4){
  segments(i,des[3,i+4],i,des[3,i+8])
  segments(i+5,des[4,i+4],i+5,des[4,i+8])
  segments(i+10,des[5,i+4],i+10,des[5,i+8])
}


# Figure 3. requirements for posting
par(mar=c(6, 4, 2, 1) + 0.1, xpd=TRUE)
plot(c(1:4,6:9,11:14,16:19,21:24),c(des[6,1:4],des[7,1:4],des[8,1:4],des[9,1:4],des[10,1:4]), pch=rep(c(18,15:17),5), ylim=c(0,1), xlim=c(0.5,24.5), ylab="Proportion of Counties with Forums",xlab="",xaxt="n", cex.axis=1.5, cex.lab=1.5, cex = 1.3)
axis(1,c(1:4,6:9,11:14,16:19,21:24),labels= rep(c("C","T1","T2","T3"),5), cex.axis=1.5, mgp=c(3,1,0))
mtext("Requires\nName", 1,at=2.5,line=4,cex=1.5)
mtext("Requires\nPhone Number",1,at=7.5,line=4,cex=1.5)
mtext("Requires\nEmail",1,at=12.5,line=4,cex=1.5)
mtext("Requires\nAddress",1,at=17.5,line=4,cex=1.5)
mtext("Requires\nID",1,at=22.5,line=4,cex=1.5)
for(i in 1:4){
  segments(i*5,-0.04,i*5,1.04)
  segments(i,des[6,i+4],i,des[6,i+8])
  segments(i+5,des[7,i+4],i+5,des[7,i+8])
  segments(i+10,des[8,i+4],i+10,des[8,i+8])
  segments(i+15,des[9,i+4],i+15,des[9,i+8])
  segments(i+20,des[10,i+4],i+20,des[10,i+8])
}


#######################
## Main Results 
#######################


est <-as.matrix(read.dta("fg_estimates.dta"))
res.t<-est[1:3,]
resp.t<-est[4:6,]

# Figure 4: causal effect of treatment on responsiveness
par(mar=c(8, 4, 1, 2) + 0.1)
plot(1:3,res.t[,1],ylim=c(-0.1,0.2),xlim=c(0.5, 3.5),main = "",ylab = "Causal Effect of Treatment on Responsiveness",pch=16,cex.lab=1.5,cex.axis=1.5, xaxt="n",xlab="",cex=2)
axis(1,1:3,labels=c("Threat of\nCollective\nAction","Threat of\nTattling\nto Superiors","Claims\nof\nLoyalty"),cex.axis=1.5,mgp=c(3,4,0))
mtext("Treatment",side=1,line=6.5,cex=1.5)
abline(h=0,lty=2)
for(i in 1:3) segments(i,res.t[i,3],i,res.t[i,4],lwd=2)


# Figure 5: causal effects of treatments on receiving publicly viewable responses
par(mar=c(8, 4, 1, 2) + 0.1)
plot(1:3,resp.t[,1],ylim=c(-0.1,0.2),xlim=c(0.5, 3.5),main = "",ylab = "Causal Effect of Treatment on Public Response",pch=16,cex.lab=1.5,cex.axis=1.5, xaxt="n",xlab="",cex=2)
axis(1,1:3,labels=c("Threat of\nCollective\nAction","Threat of\nTattling\nto Superiors","Claims\nof\nLoyalty"),cex.axis=1.5,mgp=c(3,4,0))
mtext("Treatment",side=1,line=6.5,cex=1.5)
abline(h=0,lty=2)
for(i in 1:3) 	segments(i,resp.t[i,3],i,resp.t[i,4],lwd=2)


#########################
## Content of Response
#########################

# load data
d<-read.dta("forum.dta")

# a function to generate difference in group means
eff<-function(d) {
  s<-mlogit.data(d,choice="response_content",shape="wide")
  p.long<-ddply(s,c("treat","alt"),summarize,content=mean(response_content))
  p<-reshape(p.long,timevar="alt",idvar=c("treat"),direction="wide")
  out<-rbind(p[1,],p[2:4,]-p[rep(1,3),])
  return(out[2:5])
}  

# transform data
table(d$treat,d$response_content)
d<-d[,c("city","cnty","treat","tr1","tr2","tr3","response_content")]
eff(d)

# block bootstrap
nboots<-1000
set.seed(123)
result<-array(NA,dim=c(4,4,nboots))
rownames(result)=c("control","eff1","eff2","eff3")
cities<-unique(d$city)
cnty.list<-split(d$cnty,d$city)
for (i in 1:nboots) {
  city.boot<-sample(cities,length(cities),replace=TRUE)
  cnty.boot<-unlist(cnty.list[match(city.boot,cities)])
  data.boot<-d[cnty.boot,]
  result[,,i]<-as.matrix(eff(data.boot))  # expected values
  if (floor(i/20)==i/20) cat(i) else cat(".")
}

est<-eff(d)
se<-apply(result,c(1,2),sd)
CI.lower<-apply(result,c(1,2),quantile,0.025)
CI.upper<-apply(result,c(1,2),quantile,0.975)

# Figure 6: causal effects of treamtent by reply content
par(mar=c(6, 4, 2, 1) + 0.1, xpd=FALSE)
plot(c(1:3,5:7,9:11),c(est[2,2:4],est[3,2:4],est[4,2:4]), 
     pch=rep(c(15,16,17),3), ylim=c(-0.1,0.2), xlim=c(0.5,11.5), 
     ylab="Causal Effect of Treatments on Reply Content",xlab="",xaxt="n", 
     cex.axis=1.5, cex.lab=1.5, cex=2) #cex = rep(c(1,1.3,1.2),3)
axis(1,c(0.9, 2, 3.1, 4.9, 6, 7.1, 8.9, 10, 11.1),labels= rep(c("Deferral","Referral","Direct Info"),3), cex.axis=1.4, mgp=c(3,1,0))
mtext("Threat of\nCollective Action", 1,at=2,line=4,cex=1.5)
mtext("Threat of Tattling\nto Superiors",1,at=6,line=4,cex=1.5)
mtext("Claims of\nLoyalty",1,at=10,line=4,cex=1.5)
for(i in 1:3){
  j=(i-1)*4+1
  segments(j+0,CI.lower[i+1,2],j+0,CI.upper[i+1,2], lwd=2)
  segments(j+1,CI.lower[i+1,3],j+1,CI.upper[i+1,3], lwd=2)
  segments(j+2,CI.lower[i+1,4],j+2,CI.upper[i+1,4], lwd=2)
}
abline(v=c(4,8))
abline(h=0,lty=2)

# Figure A1 in Supporting Information
est.table<-rbind(round(est[1,],3),
                 paste("(",round(se[1,],3),")",sep=""),
                 round(est[2,],3),
                 paste("(",round(se[2,],3),")",sep=""),
                 round(est[3,],3),
                 paste("(",round(se[3,],3),")",sep=""),
                 round(est[4,],3),
                 paste("(",round(se[4,],3),")",sep=""))
est.table<-cbind(c("Constant","","T1: collective action threat","","T2: tattling threat","","T3: claims of loyalty",""),est.table)
colnames(est.table)<-c("","No Response","Deferral","Referral","Information")
est.table[c(3:8,1:2),]
